pub struct StandardComparisonProductBlock {
    pub position: i32,
    pub image: Option<Box<ImageComponent>>,
    pub title: Option<String>,
    pub asin: Option<String>,
    pub highlight: Option<bool>,
    pub metrics: Option<Vec<PlainTextItem>>,
}
StandardComparisonProductBlock : The A+ Content standard comparison product block.

Fields

position: i32

The rank or index of this comparison product block within the module. Different blocks cannot occupy the same position within a single module.

image: Option<Box<ImageComponent>>title: Option<String>

The comparison product title.

asin: Option<String>

The Amazon Standard Identification Number (ASIN).

highlight: Option<bool>

Determines whether this block of content is visually highlighted.

metrics: Option<Vec<PlainTextItem>>

Comparison metrics for the product.

Implementations

The A+ Content standard comparison product block.